@@ -1,7 +1,7 @@
 /* provides a simple client program that reads ACPI status from the /proc filesystem
  *
  * Copyright (C) 2001  Grahame Bowland <grahame@angrygoats.net>
- *	    (C) 2008-2009  Michael Meskes  <meskes@debian.org>
+ *	    (C) 2008-2012  Michael Meskes  <meskes@debian.org>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -429,7 +429,7 @@ void print_ac_adapter_information(struct list *ac_adapters, int show_empty_slots
 	 fields = adapter->data;
 	while (fields) {
 	    value = fields->data;
-	    if (!strcmp(value->attr, "state") || !strcmp(value->attr, "Status"))
+	    if (!strcmp(value->attr, "state") || !strcmp(value->attr, "status"))
 		state = value->value;
 	    else if (!strcmp(value->attr, "online"))
 		state = get_unit_value(value->value) ? "on-line" : "off-line";
@@ -492,7 +492,7 @@ void print_thermal_information(struct list *thermal, int show_empty_slots, int t
 	double real_temp;
 	int i, trip_points = -1;
 
-	memset(trip, sizeof trip, 0);
+	memset(trip, 0, sizeof trip);
 	fields = sensor->data;
 	while (fields) {
 	    value = fields->data;
